aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authortobigun <tobigun@b956fd51-792f-4845-bead-9b4dfca2ff2c>2008-09-11 15:54:09 +0000
committertobigun <tobigun@b956fd51-792f-4845-bead-9b4dfca2ff2c>2008-09-11 15:54:09 +0000
commite0c41662841a34898134f6efb2222989fc816469 (patch)
tree96521de416242c78758a8562ba797c3a958e6a85
parent780d96129a06e31ed65bf4173eb18d3c7222e862 (diff)
downloadusdx-e0c41662841a34898134f6efb2222989fc816469.tar.gz
usdx-e0c41662841a34898134f6efb2222989fc816469.tar.xz
usdx-e0c41662841a34898134f6efb2222989fc816469.zip
-Creation of default directories (songs, covers) working again.
- BSD redefined to FreeBSD git-svn-id: svn://svn.code.sf.net/p/ultrastardx/svn/trunk@1365 b956fd51-792f-4845-bead-9b4dfca2ff2c
-rw-r--r--src/base/UMain.pas8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/base/UMain.pas b/src/base/UMain.pas
index c9167aa7..f9f56c3e 100644
--- a/src/base/UMain.pas
+++ b/src/base/UMain.pas
@@ -451,7 +451,7 @@ begin
// This would create a new OpenGL render-context and all texture data
// would be invalidated.
// On Linux the mode MUST be resetted, otherwise graphics will be corrupted.
- {$IF Defined(LINUX) or Defined(BSD)}
+ {$IF Defined(Linux) or Defined(FreeBSD)}
if boolean( Ini.FullScreen ) then
SDL_SetVideoMode(ScreenW, ScreenH, (Ini.Depth+1) * 16, SDL_OPENGL or SDL_FULLSCREEN)
else
@@ -472,8 +472,8 @@ begin
// FIXME: SDL_SetVideoMode creates a new OpenGL RC so we have to
// reload all texture data (-> whitescreen bug).
- // Only Linux is able to handle screen-switching this way.
- {$IF Defined(LINUX) or Defined(BSD)}
+ // Only Linux (and FreeBSD) is able to handle screen-switching this way.
+ {$IF Defined(Linux) or Defined(FreeBSD)}
if boolean( Ini.FullScreen ) then
begin
SDL_SetVideoMode(ScreenW, ScreenH, (Ini.Depth+1) * 16, SDL_OPENGL or SDL_FULLSCREEN);
@@ -1005,7 +1005,7 @@ begin
if (PathList = nil) then
PathList := TStringList.Create;
- if (Path = '') or not DirectoryExists(Path) then
+ if (Path = '') or not ForceDirectories(Path) then
Exit;
PathAbs := IncludeTrailingPathDelimiter(ExpandFileName(Path));